==========================
Broadworks OCI-P Interface
==========================


.. image:: https://img.shields.io/pypi/v/broadworks_ocip.svg
        :target: https://pypi.python.org/pypi/broadworks_ocip

.. image:: https://img.shields.io/travis/nigelm/broadworks_ocip.svg
        :target: https://travis-ci.com/nigelm/broadworks_ocip

.. image:: https://readthedocs.org/projects/broadworks-ocip/badge/?version=latest
        :target: https://broadworks-ocip.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Interfaces to the OCI-P provisioning interface of a Broadworks softswitch


* Free software: BSD license
* Documentation: https://broadworks-ocip.readthedocs.io.


Features
--------

* python objects to match all Broadworks schema objects
* API framework to talk to a Broadworks server
* additional magic to handle atuhentication and sessions
* Based on Broadworks schema R21


Credits
-------

The class is built using Michael DeHaan's `ClassForge`_ object system.

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _ClassForge: https://classforge.io/
.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
